@@ -23,22 +23,18 @@
  *
  */
 
-#ifndef LMMS_GUI_EFFECT_VIEW_H
-#define LMMS_GUI_EFFECT_VIEW_H
+#ifndef EFFECT_VIEW_H
+#define EFFECT_VIEW_H
 
 #include "AutomatableModel.h"
 #include "PluginView.h"
 #include "Effect.h"
 
-class QGraphicsOpacityEffect;
 class QGroupBox;
 class QLabel;
 class QPushButton;
 class QMdiSubWindow;
 
-namespace lmms::gui
-{
-
 class EffectControlDialog;
 class Knob;
 class LedCheckBox;
@@ -50,7 +46,7 @@ class EffectView : public PluginView
 	Q_OBJECT
 public:
 	EffectView( Effect * _model, QWidget * _parent );
-	~EffectView() override;
+	virtual ~EffectView();
 
 	inline Effect * effect()
 	{
@@ -61,30 +57,26 @@ public:
 		return castModel<Effect>();
 	}
 
-	static constexpr int DEFAULT_WIDTH = 215;
-	static constexpr int DEFAULT_HEIGHT = 60;
-	
-	void mouseMoveEvent(QMouseEvent* event) override;
-	void mousePressEvent(QMouseEvent* event) override;
-	void mouseReleaseEvent(QMouseEvent* event) override;
 
 public slots:
 	void editControls();
 	void moveUp();
 	void moveDown();
 	void deletePlugin();
+	void displayHelp();
 	void closeEffects();
 
 
 signals:
-	void movedUp(EffectView* view);
-	void movedDown(EffectView* view);
-	void deletedPlugin(EffectView* view);
+	void moveUp( EffectView * _plugin );
+	void moveDown( EffectView * _plugin );
+	void deletePlugin( EffectView * _plugin );
+
 
 protected:
-	void contextMenuEvent( QContextMenuEvent * _me ) override;
-	void paintEvent( QPaintEvent * _pe ) override;
-	void modelChanged() override;
+	virtual void contextMenuEvent( QContextMenuEvent * _me );
+	virtual void paintEvent( QPaintEvent * _pe );
+	virtual void modelChanged();
 
 
 private:
@@ -92,15 +84,10 @@ private:
 	LedCheckBox * m_bypass;
 	Knob * m_wetDry;
 	TempoSyncKnob * m_autoQuit;
+	Knob * m_gate;
 	QMdiSubWindow * m_subWindow;
 	EffectControlDialog * m_controlView;
-	
-	bool m_dragging;
-	QGraphicsOpacityEffect* m_opacityEffect;
 
 } ;
 
-
-} // namespace lmms::gui
-
-#endif // LMMS_GUI_EFFECT_VIEW_H
+#endif
