@@ -22,20 +22,16 @@
  *
  */
 
-#ifndef LMMS_GUI_INSTRUMENT_SOUND_SHAPING_VIEW_H
-#define LMMS_GUI_INSTRUMENT_SOUND_SHAPING_VIEW_H
+#ifndef INSTRUMENT_SOUND_SHAPING_VIEW_H
+#define INSTRUMENT_SOUND_SHAPING_VIEW_H
 
 #include <QWidget>
 
+#include "InstrumentSoundShaping.h"
 #include "ModelView.h"
 
 class QLabel;
 
-namespace lmms { class InstrumentSoundShaping; }
-
-namespace lmms::gui
-{
-
 class EnvelopeAndLfoView;
 class ComboBox;
 class GroupBox;
@@ -48,21 +44,18 @@ class InstrumentSoundShapingView : public QWidget, public ModelView
 	Q_OBJECT
 public:
 	InstrumentSoundShapingView( QWidget * _parent );
-	~InstrumentSoundShapingView() override;
+	virtual ~InstrumentSoundShapingView();
 
 	void setFunctionsHidden( bool hidden );
 
 
 private:
-	void modelChanged() override;
+	virtual void modelChanged();
 
 
-	InstrumentSoundShaping * m_ss = nullptr;
+	InstrumentSoundShaping * m_ss;
 	TabWidget * m_targetsTabWidget;
-
-	EnvelopeAndLfoView* m_volumeView;
-	EnvelopeAndLfoView* m_cutoffView;
-	EnvelopeAndLfoView* m_resonanceView;
+	EnvelopeAndLfoView * m_envLfoViews[InstrumentSoundShaping::NumTargets];
 
 	// filter-stuff
 	GroupBox * m_filterGroupBox;
@@ -71,9 +64,7 @@ private:
 	Knob * m_filterResKnob;
 
 	QLabel* m_singleStreamInfoLabel;
-};
 
+} ;
 
-} // namespace lmms::gui
-
-#endif // LMMS_GUI_INSTRUMENT_SOUND_SHAPING_VIEW_H
+#endif
