@@ -22,52 +22,45 @@
  *
  */
 
-#ifndef LMMS_LFO_CONTROLLER_H
-#define LMMS_LFO_CONTROLLER_H
+#ifndef LFO_CONTROLLER_H
+#define LFO_CONTROLLER_H
 
+#include <QWidget>
 
+#include "Model.h"
 #include "AutomatableModel.h"
 #include "Controller.h"
 #include "ControllerDialog.h"
-#include "SampleBuffer.h"
 #include "TempoSyncKnobModel.h"
+#include "Oscillator.h"
 
-namespace lmms
-{
-
-namespace gui
-{
-
-class AutomatableButtonGroup;
-class PixmapButton;
+class automatableButtonGroup;
 class Knob;
+class LedCheckBox;
 class TempoSyncKnob;
-
-class LfoControllerDialog;
-
-}
+class PixmapButton;
 
 
-class LfoController : public Controller
+class LfoController : public Controller 
 {
 	Q_OBJECT
 public:
 	LfoController( Model * _parent );
 
-	~LfoController() override;
+	virtual ~LfoController();
 
-	void saveSettings( QDomDocument & _doc, QDomElement & _this ) override;
-	void loadSettings( const QDomElement & _this ) override;
-	QString nodeName() const override;
+	virtual void saveSettings( QDomDocument & _doc, QDomElement & _this );
+	virtual void loadSettings( const QDomElement & _this );
+	virtual QString nodeName() const;
 
 
 public slots:
-	gui::ControllerDialog * createDialog( QWidget * _parent ) override;
+	virtual ControllerDialog * createDialog( QWidget * _parent );
 
 
 protected:
 	// The internal per-controller value updating function
-	void updateValueBuffer() override;
+	virtual void updateValueBuffer();
 
 	FloatModel m_baseModel;
 	TempoSyncKnobModel m_speedModel;
@@ -83,32 +76,30 @@ protected:
 	sample_t (*m_sampleFunction)( const float );
 
 private:
-	float m_heldSample;
-	std::shared_ptr<const SampleBuffer> m_userDefSampleBuffer = SampleBuffer::emptyBuffer();
+	SampleBuffer * m_userDefSampleBuffer;
 
 protected slots:
 	void updatePhase();
 	void updateSampleFunction();
 	void updateDuration();
 
-	friend class gui::LfoControllerDialog;
+	friend class LfoControllerDialog;
 
 } ;
 
-namespace gui
-{
+
 
 class LfoControllerDialog : public ControllerDialog
 {
 	Q_OBJECT
 public:
 	LfoControllerDialog( Controller * _controller, QWidget * _parent );
-	~LfoControllerDialog() override;
+	virtual ~LfoControllerDialog();
 
 
 protected:
-	void contextMenuEvent( QContextMenuEvent * _me ) override;
-	void modelChanged() override;
+	virtual void contextMenuEvent( QContextMenuEvent * _me );
+	virtual void modelChanged();
 
 	LfoController * m_lfo;
 
@@ -117,8 +108,8 @@ protected:
 	Knob * m_amountKnob;
 	Knob * m_phaseKnob;
 	PixmapButton * m_userLfoBtn;
-	AutomatableButtonGroup * m_waveBtnGrp;
-	AutomatableButtonGroup * m_multiplierBtnGrp;
+	automatableButtonGroup * m_waveBtnGrp;
+	automatableButtonGroup * m_multiplierBtnGrp;
 
 
 private:
@@ -129,9 +120,4 @@ private slots:
 
 } ;
 
-
-} // namespace gui
-
-} // namespace lmms
-
-#endif // LMMS_LFO_CONTROLLER_H
+#endif
