@@ -22,29 +22,25 @@
  *
  */
 
-#ifndef LMMS_GUI_MAIN_WINDOW_H
-#define LMMS_GUI_MAIN_WINDOW_H
+#ifndef MAIN_WINDOW_H
+#define MAIN_WINDOW_H
 
-#include <QBasicTimer>
-#include <QTimer>
-#include <QList>
+#include <QtCore/QBasicTimer>
+#include <QtCore/QTimer>
+#include <QtCore/QList>
 #include <QMainWindow>
-#include <QMdiArea>
+#include <QThread>
 
 #include "ConfigManager.h"
+#include "SubWindow.h"
 
 class QAction;
 class QDomElement;
 class QGridLayout;
+class QMdiArea;
 
-namespace lmms
-{
-
-namespace gui
-{
-
+class ConfigManager;
 class PluginView;
-class SubWindow;
 class ToolButton;
 
 
@@ -54,7 +50,7 @@ class MainWindow : public QMainWindow
 public:
 	QMdiArea* workspace()
 	{
-		return static_cast<QMdiArea*>(m_workspace);
+		return m_workspace;
 	}
 
 	QWidget* toolBar()
@@ -66,11 +62,9 @@ public:
 	void addSpacingToToolBar( int _size );
 
 	// wrap the widget with a window decoration and add it to the workspace
-	LMMS_EXPORT SubWindow* addWindowedWidget(QWidget *w, Qt::WindowFlags windowFlags = QFlag(0));
+	EXPORT SubWindow* addWindowedWidget(QWidget *w, Qt::WindowFlags windowFlags=0);
 
 
-	void refocus();
-
 	///
 	/// \brief	Asks whether changes made to the project are to be saved.
 	///
@@ -112,7 +106,7 @@ public:
 		return m_autoSaveTimer.interval();
 	}
 
-	enum class SessionState
+	enum SessionState
 	{
 		Normal,
 		Recover
@@ -142,13 +136,13 @@ public:
 	static void saveWidgetState( QWidget * _w, QDomElement & _de );
 	static void restoreWidgetState( QWidget * _w, const QDomElement & _de );
 
-	bool eventFilter(QObject* watched, QEvent* event) override;
-
 public slots:
 	void resetWindowTitle();
 
 	void emptySlot();
+	void enterWhatsThisMode();
 	void createNewProject();
+	void createNewProjectFromTemplate( QAction * _idx );
 	void openProject();
 	bool saveProject();
 	bool saveProjectAs();
@@ -158,14 +152,12 @@ public slots:
 	void aboutLMMS();
 	void help();
 	void toggleAutomationEditorWin();
-	void togglePatternEditorWin(bool forceShow = false);
+	void toggleBBEditorWin( bool forceShow = false );
 	void toggleSongEditorWin();
 	void toggleProjectNotesWin();
-	void toggleMicrotunerWin();
-	void toggleMixerWin();
+	void toggleFxMixerWin();
 	void togglePianoRollWin();
 	void toggleControllerRack();
-	void toggleFullscreen();
 
 	void updatePlayPauseIcons();
 
@@ -175,9 +167,6 @@ public slots:
 
 	void autoSave();
 
-private slots:
-	void onExportProjectMidi();
-
 protected:
 	void closeEvent( QCloseEvent * _ce ) override;
 	void focusOutEvent( QFocusEvent * _fe ) override;
@@ -189,37 +178,22 @@ protected:
 private:
 	MainWindow();
 	MainWindow( const MainWindow & );
-	~MainWindow() override;
+	virtual ~MainWindow();
 
 	void finalize();
 
 	void toggleWindow( QWidget *window, bool forceShow = false );
+	void refocus();
 
-	void exportProject(bool multiExport = false);
-	void handleSaveResult(QString const & filename, bool songSavedSuccessfully);
-	bool guiSaveProject();
-	bool guiSaveProjectAs( const QString & filename );
-
-	class MovableQMdiArea : public QMdiArea
-	{
-	public:
-		MovableQMdiArea(QWidget* parent = nullptr);
-		~MovableQMdiArea() {}
-	protected:
-		void mousePressEvent(QMouseEvent* event) override;
-		void mouseMoveEvent(QMouseEvent* event) override;
-		void mouseReleaseEvent(QMouseEvent* event) override;
-	private:
-		bool m_isBeingMoved;
-		int m_lastX;
-		int m_lastY;
-	};
-
-	MovableQMdiArea * m_workspace;
+	QMdiArea * m_workspace;
 
 	QWidget * m_toolBar;
 	QGridLayout * m_toolBarLayout;
 
+	QMenu * m_templatesMenu;
+	QMenu * m_recentlyOpenedProjectsMenu;
+	int m_custom_templates_count;
+
 	struct keyModifiers
 	{
 		keyModifiers() :
@@ -249,20 +223,17 @@ private:
 	ToolButton * m_metronomeToggle;
 
 	SessionState m_session;
-	
-	bool maximized;
 
 private slots:
 	void browseHelp();
+	void fillTemplatesMenu();
+	void openRecentlyOpenedProject( QAction * _action );
 	void showTool( QAction * _idx );
-	void updateViewMenu();
+	void updateRecentlyOpenedProjectsMenu();
+	void updateViewMenu( void );
 	void updateConfig( QAction * _who );
 	void onToggleMetronome();
-	void onExportProject();
-	void onExportProjectTracks();
-	void onImportProject();
-	void onSongModified();
-	void onProjectFileNameChanged();
+
 
 signals:
 	void periodicUpdate();
@@ -270,8 +241,4 @@ signals:
 
 } ;
 
-} // namespace gui
-
-} // namespace lmms
-
-#endif // LMMS_GUI_MAIN_WINDOW_H
+#endif
