@@ -22,28 +22,25 @@
  *
  */
 
-#ifndef LMMS_GUI_PLUGIN_VIEW_H
-#define LMMS_GUI_PLUGIN_VIEW_H
+#ifndef PLUGIN_VIEW_H
+#define PLUGIN_VIEW_H
 
 #include <QWidget>
 
-#include "ModelView.h"
 #include "Plugin.h"
+#include "ModelView.h"
 
-namespace lmms::gui {
 
-class LMMS_EXPORT PluginView : public QWidget, public ModelView
+class EXPORT PluginView  : public QWidget, public ModelView
 {
 public:
-	PluginView(Plugin* _plugin, QWidget* _parent)
-		: QWidget(_parent)
-		, ModelView(_plugin, this)
+	PluginView( Plugin * _plugin, QWidget * _parent ) :
+		QWidget( _parent ),
+		ModelView( _plugin, this )
 	{
 	}
 
-	virtual bool isResizable() const { return false; }
-};
+} ;
 
-} // namespace lmms::gui
 
-#endif // LMMS_GUI_PLUGIN_VIEW_H
+#endif
