@@ -22,57 +22,55 @@
  *
  */
 
-#ifndef LMMS_PROJECT_RENDERER_H
-#define LMMS_PROJECT_RENDERER_H
+#ifndef PROJECT_RENDERER_H
+#define PROJECT_RENDERER_H
 
 #include "AudioFileDevice.h"
-#include "AudioEngine.h"
+#include "lmmsconfig.h"
+#include "Mixer.h"
 #include "OutputSettings.h"
 
-#include "lmms_export.h"
 
-namespace lmms
-{
-
-
-class LMMS_EXPORT ProjectRenderer : public QThread
+class ProjectRenderer : public QThread
 {
 	Q_OBJECT
 public:
-	enum class ExportFileFormat : int
+	enum ExportFileFormats: int
 	{
-		Wave,
-		Flac,
-		Ogg,
-		MP3,
-		Count
+		WaveFile,
+		OggFile,
+		MP3File,
+		NumFileFormats
 	} ;
-	constexpr static auto NumFileFormats = static_cast<std::size_t>(ExportFileFormat::Count);
 
 	struct FileEncodeDevice
 	{
 		bool isAvailable() const { return m_getDevInst != nullptr; }
 
-		ExportFileFormat m_fileFormat;
+		ExportFileFormats m_fileFormat;
 		const char * m_description;
 		const char * m_extension;
 		AudioFileDeviceInstantiaton m_getDevInst;
 	} ;
 
-	ProjectRenderer(const OutputSettings& _os, ExportFileFormat _file_format, const QString& _out_file);
-	~ProjectRenderer() override = default;
+
+	ProjectRenderer( const Mixer::qualitySettings & _qs,
+				const OutputSettings & _os,
+				ExportFileFormats _file_format,
+				const QString & _out_file );
+	virtual ~ProjectRenderer();
 
 	bool isReady() const
 	{
-		return m_fileDev != nullptr;
+		return m_fileDev != NULL;
 	}
 
-	static ExportFileFormat getFileFormatFromExtension(
+	static ExportFileFormats getFileFormatFromExtension(
 							const QString & _ext );
 
-	static QString getFileExtensionFromFormat( ExportFileFormat fmt );
+	static QString getFileExtensionFromFormat( ExportFileFormats fmt );
 
-	static const std::array<FileEncodeDevice, 5> fileEncodeDevices;
+	static const FileEncodeDevice fileEncodeDevices[];
 
 public slots:
 	void startProcessing();
@@ -86,16 +84,14 @@ signals:
 
 
 private:
-	void run() override;
+	virtual void run();
 
 	AudioFileDevice * m_fileDev;
+	Mixer::qualitySettings m_qualitySettings;
 
 	volatile int m_progress;
 	volatile bool m_abort;
 
 } ;
 
-
-} // namespace lmms
-
-#endif // LMMS_PROJECT_RENDERER_H
+#endif
