@@ -1,5 +1,5 @@
 /*
- * endian_handling.h - handle endianness
+ * endian_handling.h - handle endianess
  *
  * Copyright (c) 2005-2014 Tobias Doerffel <tobydox/at/users.sourceforge.net>
  *
@@ -22,15 +22,12 @@
  *
  */
 
-#ifndef LMMS_ENDIAN_HANDLING_H
-#define LMMS_ENDIAN_HANDLING_H
+#ifndef ENDIAN_HANDLING_H
+#define ENDIAN_HANDLING_H
 
-#include <cstdint>
-#include <QSysInfo>
+#include <QtCore/QSysInfo>
 
-
-namespace lmms
-{
+#include "lmms_basics.h"
 
 
 inline bool isLittleEndian()
@@ -53,7 +50,4 @@ inline int32_t swap32IfBE( int32_t i )
 					( ( i & 0x000000ff ) << 24 ) );
 }
 
-
-} // namespace lmms
-
-#endif // LMMS_ENDIAN_HANDLING_H
+#endif
